@@ -15,6 +15,7 @@
 
 #include <KIconEffect>
 #include <KIconLoader>
+#include <KIconUtils>
 #include <KRatingPainter>
 #include <KStringHandler>
 
@@ -108,11 +109,20 @@ bool KStandardItemListWidgetInformant::itemIsLink(int index, const KItemListView
     return false;
 }
 
-QString KStandardItemListWidgetInformant::roleText(const QByteArray &role, const QHash<QByteArray, QVariant> &values) const
+QString KStandardItemListWidgetInformant::roleText(const QByteArray &role, const QHash<QByteArray, QVariant> &values, ForUsageAs forUsageAs) const
 {
     if (role == "rating") {
-        // Always use an empty text, as the rating is shown by the image m_rating.
-        return QString();
+        if (forUsageAs == ForUsageAs::DisplayedText) {
+            // Always use an empty text, as the rating is shown by the image m_rating.
+            return QString();
+        } else {
+            const int rating{values.value(role).toInt()};
+            // Check if there are half stars
+            if (rating % 2) {
+                return i18ncp("@accessible rating", "%1 and a half stars", "%1 and a half stars", rating / 2);
+            }
+            return i18ncp("@accessible rating", "%1 star", "%1 stars", rating / 2);
+        }
     }
     return values.value(role).toString();
 }
@@ -1658,30 +1668,12 @@ QPixmap KStandardItemListWidget::pixmapForIcon(const QString &name, const QStrin
 
         // Strangely KFileItem::overlays() returns empty string-values, so
         // we need to check first whether an overlay must be drawn at all.
-        // It is more efficient to do it here, as KIconLoader::drawOverlays()
-        // assumes that an overlay will be drawn and has some additional
-        // setup time.
         for (const QString &overlay : overlays) {
             if (!overlay.isEmpty()) {
-                int state = KIconLoader::DefaultState;
-
-                switch (mode) {
-                case QIcon::Normal:
-                    break;
-                case QIcon::Active:
-                    state = KIconLoader::ActiveState;
-                    break;
-                case QIcon::Disabled:
-                    state = KIconLoader::DisabledState;
-                    break;
-                case QIcon::Selected:
-                    state = KIconLoader::SelectedState;
-                    break;
-                }
-
                 // There is at least one overlay, draw all overlays above m_pixmap
                 // and cancel the check
-                KIconLoader::global()->drawOverlays(overlays, pixmap, KIconLoader::Desktop, state);
+                const QSize size = pixmap.size();
+                pixmap = KIconUtils::addOverlays(pixmap, overlays).pixmap(size, mode);
                 break;
             }
         }
